import request from '@/plugin/axios'
//学校管理

export function RoleList (data) {
  return request({
    url: '/role/getRoleByPage',
    method: 'post',
    data
  })
}

export function RoleSaveUpdate (data) {
  return request({
    url: '/role/saveOrUpdateRole',
    method: 'post',
    data
  })
}

export function RoleDelete (data) {
  return request({
    url: '/role/delRole',
    method: 'post',
    data
  })
}

export function RoleGetMenuTree (data) {
  return request({
    url: '/tree/getRoleMenuTree',
    method: 'post',
    data
  })
}
export function RoleGetFuncTree (data) {
  return request({
    url: '/tree/getRoleFunctionTree',
    method: 'post',
    data
  })
}
export function RoleSaveMenuTree (data) {
  return request({
    url: '/roleMenu/saveRoleMenu',
    method: 'post',
    data
  })
}
export function RoleSaveFuncTree (data) {
  return request({
    url: '/roleFunction/saveRoleFunction',
    method: 'post',
    data
  })
}
 